@@ -7,7 +7,7 @@ use utf8;
 use JSON;
 use Params::Validate qw(:all);
 
-our $VERSION = 0.002;
+our $VERSION = 0.003;
 
 =encoding utf-8
 
@@ -20,13 +20,22 @@ Chart::Dygraphs - Generate html/javascript charts from perl data using javascrip
     use Chart::Dygraphs;
     use Browser::Open qw( open_browser );
     use Path::Tiny;
+    use DateTime;
     
     my $data = [map {[$_, rand($_)]} 1..10 ];
-    my $file_temp = Path::Tiny::tempfile(UNLINK => 0);
+    my $html_file = Path::Tiny::tempfile(UNLINK => 0);
     
-    $file_temp->spew_utf8(Chart::Dygraphs::render_full_html(data => $data));
+    $html_file->spew_utf8(Chart::Dygraphs::render_full_html(data => $data));
    
-    open_browser($file_temp->canonpath()); 
+    open_browser($html_file->canonpath()); 
+
+    my $start_date = DateTime->now(time_zone => 'UTC')->truncate(to => 'hour');
+    my $time_series_data = [map {[$start_date->add(hours => 1)->clone(), rand($_)]} 1..1000];
+    
+    my $time_series_html_file = Path::Tiny::tempfile(UNLINK => 0);
+    $time_series_html_file->spew_utf8(Chart::Dygraphs::render_full_html(data => $time_series_data));
+
+    open_browser($time_series_html_file->canonpath());
      
 =head1 DESCRIPTION
 
@@ -61,7 +70,7 @@ Optional
 sub render_full_html {
     my %params = validate( @_,
                            {  data    => { type => SCALAR | ARRAYREF },
-                              options => { type => HASHREF, default => {} }
+                              options => { type => HASHREF, default => { showRangeSelector => 1 } }
                            }
     );
 
@@ -69,17 +78,22 @@ sub render_full_html {
 <html>
 <head>
 <script src="https://cdnjs.cloudflare.com/ajax/libs/dygraph/1.1.1/dygraph-combined.js"></script>
+<style>
+#graphdiv { position: absolute; left: 20px; right: 20px; top: 20px; bottom: 20px; }
+</style>
 </head>
 <body>
 <div id="graphdiv"></div>
 <script type="text/javascript">
   g = new Dygraph(
     document.getElementById("graphdiv"),
-    
 FIRST_PART_DYGRAPH
 
     my $template_second_part = <<'SECOND_PART_DYGRAPH';
   );
+
+  var range = g.yAxisRange(0);
+  g.updateOptions({valueRange: range});
 </script>
 </body>
 </html>
